menu
herdsman package
documentation
active.dart
active.dart
dark_mode
light_mode
active
library
Functions
active
(
bool
verbose
)
→ void
Activates all git hooks by setting the core.hooksPath and making hook files executable. If any error occurs during the process, it writes the error to stderr and exits with code 1.
herdsman package
documentation
active.dart
herdsman
package
Libraries
active
add
delete
init
utils/consts
utils/copy_dir
utils/hooks
active library