add library

Functions

add({required String hookName, bool verbose = false}) Future<void>
Adds a git hook by copying from the sample file. If the hook already exists, it skips the addition.
addMulti(List<String> hookNames, {bool verbose = false}) → void
Adds multiple git hooks by copying from their respective sample files. If a hook already exists, it skips the addition for that hook.