addMulti function

void addMulti(
  1. List<String> hookNames,
  2. bool verbose
)

Adds multiple git hooks by copying from their respective sample files. If a hook already exists, it skips the addition for that hook.

Implementation

void addMulti(List<String> hookNames, bool verbose) {
  for (final hookName in hookNames) {
    add(hookName, verbose);
  }
}