delete library

Functions

delete(String hookName, bool verbose) → void
Deletes a git hook by renaming it to have a .sample extension. If the hook does not exist, it skips the deletion.
deleteMulti(List<String> hookNames, bool verbose) → void
Deletes multiple git hooks by renaming them to have a .sample extension. If a hook does not exist, it skips the deletion for that hook.