deleteMulti function
Deletes multiple git hooks by renaming them to have a .sample extension. If a hook does not exist, it skips the deletion for that hook.
Implementation
void deleteMulti(List<String> hookNames, {bool verbose = false}) {
for (final hookName in hookNames) {
delete(hookName: hookName, verbose: verbose);
}
}