utils/hooks library

Constants

hooks → const List<String>
List of standard Git hook names

Functions

deactiveHooks() List<String>
Returns the list of deactivated git hook file paths
getHooks() List<String>
Returns the list of active git hook file paths