active library

Functions

active(bool verbose) → void
Activates all git hooks by setting the core.hooksPath and making hook files executable. If any error occurs during the process, it writes the error to stderr and exits with code 1.