add library

Functions

add(String hookName, bool verbose) Future<void>
Adds a git hook by copying from the sample file. If the hook already exists, it skips the addition.
addMulti(List<String> hookNames, bool verbose) → void
Adds multiple git hooks by copying from their respective sample files. If a hook already exists, it skips the addition for that hook.