addMulti function
Adds multiple git hooks by copying from their respective sample files. If a hook already exists, it skips the addition for that hook.
Implementation
void addMulti(List<String> hookNames, {bool verbose = false}) {
for (final hookName in hookNames) {
add(hookName: hookName, verbose: verbose);
}
}