menu
herdsman package
documentation
init.dart
init.dart
dark_mode
light_mode
init
library
Functions
init
(
bool
verbose
)
→ void
Initializes the herdsman git hooks directory by copying existing hooks from the .git/hooks directory and setting the git core.hooksPath. If the herdsman directory already exists, it prompts the user for confirmation before replacing it.
herdsman package
documentation
init.dart
herdsman
package
Libraries
active
add
delete
init
utils/consts
utils/copy_dir
utils/hooks
init library