init library

Functions

init({bool verbose = false}) Future<void>
Initializes the herdsman git hooks directory by copying existing hooks from the .git/hooks directory and setting the git core.hooksPath. If the herdsman directory already exists, it prompts the user for confirmation before replacing it.