menu
herdsman package
documentation
utils/hooks.dart
utils/hooks.dart
dark_mode
light_mode
utils/hooks
library
Constants
hooks
→ const
List
<
String
>
List of standard Git hook names
Functions
deactiveHooks
(
)
→
List
<
String
>
Returns the list of deactivated git hook file paths
getHooks
(
)
→
List
<
String
>
Returns the list of active git hook file paths
herdsman package
documentation
utils/hooks.dart
herdsman
package
Libraries
active
add
delete
init
utils/consts
utils/copy_dir
utils/hooks
hooks library